#
# spec file for package webp-pixbuf-loader
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           webp-pixbuf-loader
Version:        0.2.7
Release:        bp160.1.6
Summary:        WebP GDK Pixbuf Loader library
License:        LGPL-2.0-or-later
URL:            https://github.com/aruiz/webp-pixbuf-loader
Source:         %{url}/archive/refs/tags/%{version}.tar.gz#/%{name}-%{version}.tar.gz
BuildRequires:  gdk-pixbuf-thumbnailer
BuildRequires:  meson
BuildRequires:  pkgconfig
BuildRequires:  pkgconfig(gdk-pixbuf-2.0) > 2.22.0
BuildRequires:  pkgconfig(libwebp) >= 1.3.2
Requires:       gdk-pixbuf-query-loaders
Requires:       gdk-pixbuf-thumbnailer
%gdk_pixbuf_loader_requires

%description
webp-pixbuf-loader is a plugin to allow loading WebP images in GTK+ applications.

%prep
%autosetup -p1

%build
%meson
%meson_build

%install
%meson_install

%check
%meson_test

%post
%gdk_pixbuf_loader_post

%postun
%gdk_pixbuf_loader_postun

%files
%license LICENSE.LGPL-2
%doc README.md
%{_libdir}/gdk-pixbuf-2.0/*/loaders/libpixbufloader-webp.so
%{_datadir}/thumbnailers/webp-pixbuf.thumbnailer

%changelog
* Tue Aug  6 2024 Joshua Smith <smolsheep@opensuse.org>
- Enable tests
- Update to 0.2.7:
  * Fixes prepare/Update signal emitions and support for 0ms frames
- Updates from 0.2.6:
  * meson.build file had >1.3.2 rather than >=1.3.2 as the required
    version for libwebp
- Updates from 0.2.5:
  * libwebp 1.3.2 onwards is a requirement now due to security
    vulnerability in libwebp
- Updates from 0.2.4:
  * Improves gdk_pixbuf_get_file_info performance by not doing any
    allocations.
- Updates from 0.2.3:
  * fix crash when jpeg is named as .webp
- Updates from 0.2.2:
  * adds ICC profile data read support, when a webp file includes
    ICC data it embeds the data encoded as base64 into the
    GdkPixbuf object as an option. The data can be retrieved using
    gdk_pixbuf_get_option(pixbuf, "icc-profile");
- Updates from 0.2.1:
  * Adds ICC profile support through the "icc-profile" property
    encoded in base64 for all gdk_pixbuf_save operations
  * Fixes a crash when NULL is passed to the GError** to save
    operations
- Updates from 0.2.0:
  * This release brings all the same features, improves testing,
    does not require endian specific code, and has removed a memory
    leak that was complicated to solve in the previous
    implementation.
- Updates from 0.1.2:
  * bring back save functionality
  * tests: add save test and rework test infrastructure
- Updates from 0.1.1:
  * simplify method naming and order implementations
  * configure decoder output to write in pixbuf
- Updates from 0.1.0:
  * Simplified implementation of both static and animated webp
    implementation
  * Fix: exchanging animation for static image leaks memory
- Updates from 0.0.7:
  * meson improvements and BSD compatibility
* Sat Sep 24 2022 Dingzhong Chen <wsxy162@gmail.com>
- Update to 0.0.6
- Changes since initial package version (0.0.3)
  * Add initial GitHub Actions CI script
  * meson: automatically detect gdk-pixbuf-query-loaders path on Debian
  * io-webp.io: Fixes endianess bug while reading values from buffer
  * Added checking return value of 2 function calls
  * Fix crash when gdk_pixbuf_file_info is called on a webp file
  * Adds animation support and adds macOS fixes
* Sat Aug  7 2021 Atri Bhattacharya <badshah400@gmail.com>
- Initial package.
